AuthService class

Constructors

AuthService(WebRequestService webRequestService)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webRequestService → WebRequestService
final

Methods

getCurrentUser() → Future<GetCurrentUserDetailsResult>
login(UserLoginCommand command) → Future<UserLoginCommandResult>
logout() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signInWithGoogleJwt(SignInWithGoogleJwtCommandRequest request) → Future<SignInWithGoogleJwtResult>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited