SignInWithGoogleJwtCommand class
- Inheritance
-
- Object
- WebRequest<
SignInWithGoogleJwtResult> - PostWebRequest<
SignInWithGoogleJwtResult> - SignInWithGoogleJwtCommand
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → SignInWithGoogleJwtCommandRequest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verb → HttpVerb
-
finalinherited
Methods
-
getJsonBody(
) → Map< String, dynamic> -
override
-
getPath(
) → String -
override
-
getQueryParameters(
) → Map< String, dynamic> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toResponse(
Map< String, dynamic> json) → SignInWithGoogleJwtResult -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited