SignInWithGoogleJwtResult class

Constructors

SignInWithGoogleJwtResult({required bool isAuthenticated, UserModel? user, required bool isNewUser})
SignInWithGoogleJwtResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isAuthenticated bool
final
isNewUser bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user UserModel?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited