GoogleSignInCommand class

Constructors

GoogleSignInCommand({required String email, required String displayName, required String id, String? photoUrl, String? accessToken, String? idToken})
const
GoogleSignInCommand.fromJson(Map<String, dynamic> json)
factory

Properties

accessToken String?
final
displayName String
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
idToken String?
final
photoUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited