UserLoginState class

Constructors

UserLoginState({String? userName, String? password, bool isLoading = false, String? errorMessage, bool isSuccess = false})

Properties

errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isLoading → bool
final
isSuccess → bool
final
password → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userName → String?
final

Methods

copyWith({Object? userName = _sentinal, Object? password = _sentinal, bool? isLoading, String? errorMessage, bool? isSuccess}) → UserLoginState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited