UserLoginViewModel class

Constructors

UserLoginViewModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
ref → AutoDisposeNotifierProviderRef<UserLoginState>
The Ref from the provider associated with this Notifier.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ UserLoginState
The value currently exposed by this Notifier.
getter/setter pairinherited
stateOrNull → UserLoginState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() → UserLoginState
Initialize an AsyncNotifier.
listenSelf(void listener(UserLoginState? previous, UserLoginState next), {void onError(Object error, StackTrace stackTrace)?}) → void
Listens to changes on the value exposed by this provider.
inherited
login() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPassword(String password) → void
setUsername(String username) → void
toString() → String
A string representation of this object.
inherited
updateShouldNotify(UserLoginState previous, UserLoginState next) → bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited