UserService class

Constructors

UserService({required AuthService authService, required AppConfigurationState appConfigurationState})

Properties

appConfigurationState → AppConfigurationState
final
authService → AuthService
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userLoggedInStream → Stream<UserModel>
no setter

Methods

getUserDetails() → Future<UserModel?>
initializeGoogleSignIn() → Future<void>
initializeSignInProviders() → Future<void>
login(UserLoginCommand command) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signInWithGoogle(String idToken) → Future<void>
toString() → String
A string representation of this object.
inherited
tryAutoLogin() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited