AppConfigurationState class
Constructors
-
AppConfigurationState({List<
ApiEndpointBase> apiEndpoints = const [], bool isInitialized = false, String? googleClientId, bool useTraditionalLogin = false}) - AppConfigurationState.empty()
-
factory
-
AppConfigurationState.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
apiEndpoints
→ List<
ApiEndpointBase> -
final
- defaultApiEndpoint → ApiEndpointBase
-
no setter
- googleClientId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useTraditionalLogin → bool
-
final
Methods
-
copyWith(
{List< ApiEndpointBase> ? apiEndpoints, bool? isInitialized, String? googleClientId, bool? useTraditionalLogin}) → AppConfigurationState -
getApiEndpoint(
String apiKey) → ApiEndpointBase -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited