AppInitializationService class

Constructors

AppInitializationService({required AppStartupService appStartupService, required UserService userService, required DioService dioService})

Properties

appStartupService → AppStartupService
final
dioService → DioService
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userService → UserService
final

Methods

initializeApplication() → Future<AppInitializationResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited