ApplicationManagerService class

Constructors

ApplicationManagerService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
ref → NotifierProviderRef<ApplicationState>
The Ref from the provider associated with this Notifier.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ ApplicationState
The value currently exposed by this Notifier.
getter/setter pairinherited
stateOrNull → ApplicationState?
The value currently exposed by this Notifier.
no setterinherited

Methods

autoLoginFailed() → void
build() → ApplicationState
Initialize a Notifier.
changeSection(String section) → void
clearCurrentUser() → void
initializeApplication() → Future<void>
listenSelf(void listener(ApplicationState? previous, ApplicationState next), {void onError(Object error, StackTrace stackTrace)?}) → void
Listens to changes on the value exposed by this provider.
inherited
loadConfiguration() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrentUser(UserModel? user) → void
startApplication() → Future<void>
toString() → String
A string representation of this object.
inherited
updateShouldNotify(ApplicationState previous, ApplicationState next) → bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited