ApplicationSection class

Constructors

ApplicationSection({required String id, required String title, required IconData icon, required String route, required WidgetBuilder builder, required bool requiresAuthentication})

Properties

builder → WidgetBuilder
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
id → String
final
requiresAuthentication → bool
final
route → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, WidgetBuilder>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited