EventBroker class

Constructors

EventBroker()

Properties

hashCode int
The hash code for this object.
no setterinherited
ref → NotifierProviderRef<EventQueueState>
The Ref from the provider associated with this Notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state EventQueueState
The value currently exposed by this Notifier.
getter/setter pairinherited
stateOrNull EventQueueState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() EventQueueState
Initialize a Notifier.
listenSelf(void listener(EventQueueState? previous, EventQueueState next), {void onError(Object error, StackTrace stackTrace)?}) → void
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish<TEvent extends ApplicationEvent>(TEvent event) Future<void>
toString() String
A string representation of this object.
inherited
updateShouldNotify(EventQueueState previous, EventQueueState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited