EventProvider<TEvent> class

Constructors

EventProvider({required dynamic onPublish(EventBroker eventBroker, TEvent event), required TEvent eventFactory()})

Properties

eventFactory → TEvent Function()
final
hashCode int
The hash code for this object.
no setterinherited
onPublish → dynamic Function(EventBroker eventBroker, TEvent event)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(EventBroker eventBroker) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create<T extends ApplicationEvent>(T eventFactory()) EventProvider<T>