ViewModelEventEntry class

Constructors

ViewModelEventEntry({required bool shouldHandle(ViewModelEvent), required dynamic handler(ViewModelEvent)})

Properties

handler → dynamic Function(ViewModelEvent)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldHandle bool Function(ViewModelEvent)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create<TEvent extends ViewModelEvent>(dynamic handler(TEvent)) ViewModelEventEntry