ViewModelEventEntryListBuilder class

Properties

eventEntries List<ViewModelEventEntry>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() List<ViewModelEventEntry>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withEvent<TEvent extends ViewModelEvent>(dynamic handler(TEvent)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited