LoadableState<T> class

Constructors

LoadableState({bool isLoading = false, T? data, String? errorMessage, bool hasLoaded = false})
const
LoadableState.startWithLoading()
factory
LoadableState.withData(T? data)
factory
LoadableState.withErrorMessage(String? errorMessage)
factory

Properties

data → T?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
hasLoaded bool
final
isLoading bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isLoading, T? data, String? errorMessage, bool? hasLoaded}) LoadableState<T>
copyWithData(T? data) LoadableState<T>
copyWithErrorMessage(String? errorMessage) LoadableState<T>
copyWithLoading() LoadableState<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited