Mediator class

Constructors

Mediator(MediatorRequestHandlerMapping _handlerMapping, EventBroker _eventBroker)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasHandler<TRequest>() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerHandler<TRequest, TResponse>(Provider<RequestHandler<TRequest, TResponse>> handlerProvider, Ref<Object?> ref) → void
send<TRequest, TResponse>(TRequest request) Future<MediatorResultTyped<TResponse>>
sendWithEventOnSuccess<TRequest, TResponse, TEvent extends ApplicationEvent>({required TRequest request, required TEvent eventFactory(TResponse)}) Future<MediatorResultTyped<TResponse>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited