SubscriptionManager class
Constructors
- SubscriptionManager({required EventBroker eventBroker, String? scopeId})
Properties
- eventBroker → EventBroker
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildSubscriptions(
Ref< Object?> ref, dynamic buildEntries(EventSubscriptionEntryListBuilder)) → void -
buildWidgetSubscriptions(
WidgetRef ref, dynamic buildEntries(EventSubscriptionEntryListBuilder)) → void