CookieJarService class

Constructors

CookieJarService()

Properties

future Future<CookieJarServiceState>
Obtains a Future that resolves with the first state value that is not AsyncLoading.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ref → AsyncNotifierProviderRef<CookieJarServiceState>
The Ref from the provider associated with this AsyncNotifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ AsyncValue<CookieJarServiceState>
The value currently exposed by this AsyncNotifier.
getter/setter pairinherited

Methods

build() Future<CookieJarServiceState>
Initialize an AsyncNotifier.
initCookieJar() Future<PersistCookieJar>
listenSelf(void listener(AsyncValue<CookieJarServiceState>? previous, AsyncValue<CookieJarServiceState> next), {void onError(Object error, StackTrace stackTrace)?}) → void
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(FutureOr<CookieJarServiceState> cb(CookieJarServiceState), {FutureOr<CookieJarServiceState> onError(Object err, StackTrace stackTrace)?}) Future<CookieJarServiceState>
A function to update state from its previous value, while abstracting loading/error cases for state.
inherited
updateShouldNotify(AsyncValue<CookieJarServiceState> previous, AsyncValue<CookieJarServiceState> next) bool
A method invoked when the state exposed by this AsyncNotifier changes.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited