IPagingDetails class abstract

Inheritance
Implementers

Constructors

IPagingDetails()

Properties

currentPage → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortField → String
no setterinherited
sortOrder → String
no setterinherited
totalItems → int
no setter

Methods

getOffset() → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited