GetWebRequestHandler<TRequest, TResponse> class abstract

Implemented types

Constructors

GetWebRequestHandler({required WebRequestService requestService})

Properties

hashCode int
The hash code for this object.
no setterinherited
requestService WebRequestService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(TRequest request) Future<TResponse>
override
getPath(TRequest request) String
getQueryParameters(TRequest request) Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toResponse(Map<String, dynamic> json) → TResponse
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited