WebRequestService class

Constructors

WebRequestService({required ApplicationManagerService appManager, required String baseUrl, required DioService dioService})

Properties

appManager → ApplicationManagerService
final
baseUrl → String
final
dioService → DioService
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete({required String path}) → Future<WebResponse>
get({required String path, Map<String, dynamic>? queryParams}) → Future<WebResponse>
getRequest<T>(GetWebRequest<T> request) → Future<WebResponseTyped<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post({required String path, required Map<String, dynamic>? jsonBody}) → Future<WebResponse>
postRequest<T>(PostWebRequest<T> request) → Future<WebResponseTyped<T>>
put({required String path, required Map<String, dynamic>? jsonBody}) → Future<WebResponse>
putRequest<T>(PutWebRequest<T> request) → Future<WebResponseTyped<T>>
request<T>(WebRequest<T> request) → Future<WebResponseTyped<T>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited