ButtonOptions class
Constructors
- ButtonOptions({String? text, bool isEnabled = true, ButtonStyleOptions? style})
- ButtonOptions.fromText(String text, {bool isEnabled = true})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ButtonStyleOptions?
-
final
- text → String?
-
final
Methods
-
copyWith(
{String? text, bool? isEnabled}) → ButtonOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited