CardOptions class
Constructors
- CardOptions({EdgeInsets contentPadding = const EdgeInsets.all(16.0), bool contentIsExpanded = false})
-
const
- CardOptions.zeroPadding({bool contentIsExpanded = false})
-
factory
Properties
- contentIsExpanded → bool
-
final
- contentPadding → EdgeInsets
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited