LoadableStateContainerOptions class
Constructors
- LoadableStateContainerOptions({String nullStateMessage = "No data", bool isLoading = false})
-
const
- LoadableStateContainerOptions.withNullStateMessage(String nullStateMessage)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
final
- nullStateMessage → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited