FormButtonsConfiguration class

Constructors

FormButtonsConfiguration({FormButtonOptions? cancelButton, FormButtonOptions? saveButton, FormButtonOptions? nextButton, FormButtonOptions? previousButton})
FormButtonsConfiguration.nextAndPrevious({bool showPrevious = true, bool showNext = true, bool nextEnabled = true, String nextLabel = "Next"})
factory
FormButtonsConfiguration.saveAndCancel({bool saveEnabled = true})
factory

Properties

cancelButton FormButtonOptions?
final
hashCode int
The hash code for this object.
no setterinherited
nextButton FormButtonOptions?
final
previousButton FormButtonOptions?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveButton FormButtonOptions?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited