NumberFormFieldDetails class
- Inheritance
-
- Object
- FormFieldDetails
- NumberFormFieldDetails
Constructors
Properties
- fieldName → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRequired → bool
-
finalinherited
- label → String?
-
finalinherited
- max → int?
-
final
- min → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → FormFieldType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited