FlowControllerViewModel class

Inheritance

Constructors

FlowControllerViewModel()

Properties

arg FormFlowProfile
The argument that was passed to this family.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
ref → AutoDisposeNotifierProviderRef<FlowControllerState>
The Ref from the provider associated with this Notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FlowControllerState
The value currently exposed by this Notifier.
getter/setter pairinherited
stateOrNull FlowControllerState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build(FormFlowProfile profile) FlowControllerState
Initialize an AsyncNotifier.
clearError() → void
inherited
executeOperation<TResult>(Future<TResult> operation(), dynamic onSuccess(TResult)) Future<void>
inherited
listenSelf(void listener(FlowControllerState? previous, FlowControllerState next), {void onError(Object error, StackTrace stackTrace)?}) → void
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(FlowControllerState previous, FlowControllerState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited