FormProfileRow class
Constructors
-
FormProfileRow({required List<
FormRowItem> items}) -
FormProfileRow.allExpandable(List<
FormFieldMapping> fields) -
factory
- FormProfileRow.singleExpandable(FormFieldMapping field)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
FormRowItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited