StandardFormProfileGroup class
- Inheritance
-
- Object
- FormProfileGroup
- StandardFormProfileGroup
Constructors
-
StandardFormProfileGroup({required String title, required List<
FormProfileRow> rows})
Properties
- groupTypeId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rows
→ List<
FormProfileRow> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited