FormRowItem class
Constructors
- FormRowItem({required FormFieldMapping field, int flex = 1, double? width, bool expandable = false})
- FormRowItem.expandable(FormFieldMapping field)
-
factory
- FormRowItem.width(FormFieldMapping field, double width)
-
factory
Properties
- expandable → bool
-
final
- field → FormFieldMapping
-
final
- flex → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited