TextInputOptions class

Constructors

TextInputOptions({required String label, required bool isRequired, int? maxLength, bool autoFocus = false})

Properties

autoFocus bool
final
hashCode int
The hash code for this object.
no setterinherited
isRequired bool
final
label String
final
maxLength int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? label, bool? isRequired, int? maxLength, bool? autoFocus}) TextInputOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited