ResponsiveBreakpoints class

Breakpoint definitions for responsive design

Constructors

ResponsiveBreakpoints({double mobile = 600, double tablet = 900, double desktop = 1200, double largeDesktop = 1600})
const

Properties

desktop → double
Desktop breakpoint (default: 1200px)
final
hashCode → int
The hash code for this object.
no setterinherited
largeDesktop → double
Large desktop breakpoint (default: 1600px)
final
mobile → double
Mobile phone breakpoint (default: 600px)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tablet → double
Tablet breakpoint (default: 900px)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited