ResponsiveUtils class

Utility class for responsive design helpers

Constructors

ResponsiveUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getScreenHeight(BuildContext context) → double
Gets the current screen height
getScreenSize(BuildContext context) → ScreenSize
Gets the current screen size from BuildContext
getScreenWidth(BuildContext context) → double
Gets the current screen width
isDesktopOrLarger(BuildContext context) → bool
Checks if the current screen size is desktop or larger
isMobile(BuildContext context) → bool
Checks if the current screen size is mobile
isTabletOrLarger(BuildContext context) → bool
Checks if the current screen size is tablet or larger