TabbedHeaderTab<TKey> class

Constructors

TabbedHeaderTab({required TKey key, required String title, required WidgetBuilder contentBuilder, List<Widget>? actions})

Properties

actions → List<Widget>?
final
contentBuilder → WidgetBuilder
final
hashCode → int
The hash code for this object.
no setterinherited
key → TKey
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited