SearchRequestListGeneric<TRequest, TResult, TItem> class

Inheritance

Constructors

SearchRequestListGeneric({Key? key, required TRequest searchRequest, required Widget itemBuilder(TItem item, int index, ScreenSize screenSize), dynamic searchTextChanged(String searchText)?, String searchInputHint = 'Search', CardOptions? listCardOptions, bool showListCard = true, dynamic onItemTap(TItem item)?, required List<TItem> itemsFactory(TResult result)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(TItem item, int index, ScreenSize screenSize)
final
itemsFactory List<TItem> Function(TResult result)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listCardOptions CardOptions?
final
onItemTap → dynamic Function(TItem item)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchInputHint String
final
searchRequest → TRequest
final
searchTextChanged → dynamic Function(String searchText)?
final
showListCard bool
final

Methods

createElement() → ConsumerStatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ConsumerState<SearchRequestListGeneric<TRequest, TResult, TItem>>
Creates the mutable state for this widget at a given location in the tree.
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited