MediatorRequestHandlerMapping class

Properties

count int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
getHandler<TRequest, TResponse>() RequestHandler<TRequest, TResponse>?
getHandlerByType<TResponse>(Type requestType) RequestHandler?
hasHandler<TRequest>() bool
merge(MediatorRequestHandlerMapping other) MediatorRequestHandlerMapping
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<TRequest, TResponse>(Provider<RequestHandler<TRequest, TResponse>> handlerProvider, Ref<Object?> ref) MediatorRequestHandlerMapping
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited