EventSubscriptionEntry class
Constructors
- EventSubscriptionEntry({required bool matchesType(ApplicationEvent), required dynamic handler(ApplicationEvent), bool passesCriteria(ApplicationEvent)?, String? scopeId})
Properties
- handler → dynamic Function(ApplicationEvent)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchesType → bool Function(ApplicationEvent)
-
final
- passesCriteria → bool Function(ApplicationEvent)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldHandle(
ApplicationEvent event) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create<
TEvent extends ApplicationEvent> (dynamic handler(TEvent), {String? scopeId}) → EventSubscriptionEntry