EventSubscriptionEntryListBuilder class
Constructors
Properties
-
entries
→ List<
EventSubscriptionEntry> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → List< EventSubscriptionEntry> -
buildByType<
TEvent extends ApplicationEvent> (TEvent event) → List< EventSubscriptionEntry> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withEvent<
TEvent extends ApplicationEvent> ({required dynamic handler(TEvent), bool passesCriteria(TEvent)?, String? scopeId}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited