WebRequestHandler<TRequest, TResponse> class
abstract
- Implemented types
-
- RequestHandler<
TRequest, TResponse>
- RequestHandler<
Constructors
- WebRequestHandler({required WebRequestService requestService, required HttpVerb verb})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestService → WebRequestService
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verb → HttpVerb
-
final
Methods
-
execute(
TRequest request) → Future< TResponse> -
override
-
getJsonBody(
) → Map< String, dynamic> -
getPath(
) → String -
getQueryParameters(
TRequest request) → Map< String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toResponse(
Map< String, dynamic> json) → TResponse -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited