WebResponse class
Constructors
-
WebResponse({Map<
String, dynamic> ? body, WebRequestResult result = WebRequestResult.ok}) -
WebResponse.badRequest(Map<
String, dynamic> ? body) -
factory
-
WebResponse.systemError(Map<
String, dynamic> ? body) -
factory
-
WebResponse.unAuthorized(Map<
String, dynamic> ? body) -
factory
Properties
-
body
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → WebRequestResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited