FormFieldDetails class abstract
- Implementers
Constructors
- FormFieldDetails({String? label, required String fieldName, required bool isRequired, required FormFieldType type})
Properties
- fieldName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRequired → bool
-
final
- label → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → FormFieldType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited