FlowControllerState class
- Inheritance
-
- Object
- ViewState
- ViewStateBase<
FlowControllerState> - FlowControllerState
Constructors
- FlowControllerState({bool isLoading = false, String? errorMessage, required FormFlowProfile profile})
Properties
- errorMessage → String?
-
finalinherited
- hasError → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
finalinherited
- profile → FormFlowProfile
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearError(
) → FlowControllerState -
inherited
-
copyWith(
{bool? isLoading, String? errorMessage, FormFlowProfile? profile}) → FlowControllerState -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withError(
String message) → FlowControllerState -
inherited
-
withLoaded(
) → FlowControllerState -
inherited
-
withLoading(
) → FlowControllerState -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited