FlowState class

Constructors

FlowState({required int currentStepIndex, required int currentPanelIndex, required int stepCount})
FlowState.initial(int stepCount)
factory

Properties

canGoNext bool
no setter
canGoPrevious bool
no setter
currentPanelIndex int
final
currentStepIndex int
final
hashCode int
The hash code for this object.
no setterinherited
nextLabel String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepCount int
final

Methods

copyWith({int? currentStepIndex, int? currentPanelIndex, int? stepCount}) FlowState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNextPanel() FlowState
toNextStep() FlowState
toPreviousPanel() FlowState
toPreviousStep() FlowState
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited